==> zabbix_5.0.0.orig.tar.gz: zabbix-5.0.0/src/go/plugins/system/swap/swap_windows.go <==
// +build windows

/*
** Zabbix
** Copyright (C) 2001-2020 Zabbix SIA
**
** This program is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License as published by
** the Free Software Foundation; either version 2 of the License, or
** (at your option) any later version.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
** GNU General Public License for more details.
**
** You should have received a copy of the GNU General Public License
** along with this program; if not, write to the Free Software
** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
**/

package swap

import (
	"errors"

	"zabbix.com/pkg/plugin"
	"zabbix.com/pkg/win32"
)

// Plugin -
type Plugin struct {
	plugin.Base
}

var impl Plugin

// Export -
func (p *Plugin) Export(key string, params []string, ctx plugin.ContextProvider) (result interface{}, err error) {
	if key != "system.swap.size" {
		return nil, plugin.UnsupportedMetricError
	}

	if len(params) > 2 {
		return nil, errors.New("Too many parameters.")
	}

	var mode string
	if len(params) == 2 && params[1] != "" {
		mode = params[1]
	}

	if len(params) > 0 && params[0] != "" && params[0] != "all" {
		return nil, errors.New("Invalid first parameter.")
	}

	m, err := win32.GlobalMemoryStatusEx()
	if err != nil {
		return
	}

	var total, avail uint64
	if m.TotalPageFile > m.TotalPhys {
		total = m.TotalPageFile - m.TotalPhys
	}
	if m.AvailPageFile > m.AvailPhys {
		avail = m.AvailPageFile - m.AvailPhys
	}
	if avail > total {
		avail = total
	}

	switch mode {
	case "", "total":
		return total, nil
	case "free":
		return avail, nil
	case "used":
		return total - avail, nil
	case "pfree":
		return float64(avail) / float64(total) * 100, nil
	case "pused":
		return float64(total-avail) / float64(total) * 100, nil
	default:
		return nil, errors.New("Invalid second parameter.")
	}
}

func init() {
	plugin.RegisterMetrics(&impl, "Swap",
		"system.swap.size", "Returns Swap space size in bytes or in percentage from total.",
	)
}

==> zabbix-6.4.20rc1.tar.gz: zabbix-6.4.20rc1/src/go/plugins/system/swap/swap_windows.go <==
//go:build windows
// +build windows

/*
** Zabbix
** Copyright (C) 2001-2024 Zabbix SIA
**
** This program is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License as published by
** the Free Software Foundation; either version 2 of the License, or
** (at your option) any later version.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
** GNU General Public License for more details.
**
** You should have received a copy of the GNU General Public License
** along with this program; if not, write to the Free Software
** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
**/

package swap

import (
	"golang.zabbix.com/agent2/pkg/win32"
	"golang.zabbix.com/sdk/errs"
	"golang.zabbix.com/sdk/plugin"
)

func init() {
	err := plugin.RegisterMetrics(&impl, "Swap",
		"system.swap.size", "Returns Swap space size in bytes or in percentage from total.",
	)
	if err != nil {
		panic(errs.Wrap(err, "failed to register metrics"))
	}
}

func getSwapSize() (uint64, uint64, error) {
	m, err := win32.GlobalMemoryStatusEx()
	if err != nil {
		return 0, 0, nil
	}

	var total, avail uint64
	if m.TotalPageFile > m.TotalPhys {
		total = m.TotalPageFile - m.TotalPhys
	}
	if m.AvailPageFile > m.AvailPhys {
		avail = m.AvailPageFile - m.AvailPhys
	}

	return total, avail, nil
}

func getSwapStatsIn(string) (uint64, uint64, uint64, error) {
	return 0, 0, 0, plugin.UnsupportedMetricError
}

func getSwapStatsOut(string) (uint64, uint64, uint64, error) {
	return 0, 0, 0, plugin.UnsupportedMetricError
}
